pub struct AssociatedItem {
    pub asin: Option<String>,
    pub title: Option<String>,
    pub quantity: Option<i32>,
    pub order_id: Option<String>,
    pub item_status: Option<ItemStatus>,
    pub brand_name: Option<String>,
    pub item_delivery: Option<Box<ItemDelivery>>,
}
AssociatedItem : Information about an item associated with the service job.

Fields

asin: Option<String>

The Amazon Standard Identification Number (ASIN) of the item.

title: Option<String>

The title of the item.

quantity: Option<i32>

The total number of items included in the order.

order_id: Option<String>

The Amazon-defined identifier for an order placed by the buyer, in 3-7-7 format.

item_status: Option<ItemStatus>

The status of the item.

brand_name: Option<String>

The brand name of the item.

item_delivery: Option<Box<ItemDelivery>>

Implementations

Information about an item associated with the service job.